%
%   Fading channel
%   The normalized fading rate = f_dm/1/T = N_fdm/NN
%
%    function rayleigh=Rayleigh_fading(fdmT, NN)
%	fdm=1/2^ii, NN=2^jj
%
%   Example: channel=Rayleigh_fading(1/2^3, 10);
%   Use for fast fading. Not good for use with smaller fading rate.
%

function rayleigh=Rayleigh_fading(fdmT, NN)
  %fdmT=1/2^3;
  %NN=2^10;

% This has been setup at 2^8 for accuracy. It should be at least greater than 9.
Nfdm=2^8;

NN1=Nfdm/fdmT;
small_val=0.01;

if NN1 < NN,
    Nfdm=fdmT*NN;
    NN1=NN;
end    
  
KK=log2(NN1/Nfdm);

f=0:Nfdm;f=f-small_val;
% generate Nfdm values of sqrt of the Doppler spectrum coefficients
Sf=(pi*sqrt(1-(f/Nfdm).^2)).^(-1/4);
% The filter is
Filter2=[Sf zeros(1,NN1-2*Nfdm-1) fliplr(Sf(1,2:Nfdm+1))];
% normalize the filter
% I can verify this method by time_filter=fft(Filter), 
% and then norm_Filter=ifft(time_filter/norm(time_filter)).
time_filter=ifft(Filter2);time_filter=time_filter/norm(time_filter);
Filter=fft(time_filter);

%figure(2), clf,semilogy(Sf);figure(1)
% Generate the independant time-domain gaussian process
gt=sqrt(.5)*(randn(1, NN1)+j*randn(1,NN1));
Gt=fft(gt);

Rf=Filter.*Gt;
rayleigh1=ifft(Rf);

% Return the first NN number of samples, because that's what was asked
rayleigh=rayleigh1(1,1:NN);


% clf
% plot(real(rayleigh),'-y');hold on;
% plot(imag(rayleigh),'-r');hold off;

